extern crate classreader;

//use classreader as c;

fn main() {
    //let cls = c::ClassReader::new_from_path("/home/werner/test/pkg/Test.class").unwrap();

    //println!("class with magic 0x{:X}, v{}.{}", cls.magic, cls.major_version, cls.minor_version)
    //println!("{:?}", cls);
}
